#ifndef _LOCAL_MATH_H
#define _LOCAL_MATH_H
#include <math.h>

#ifndef M_LN2l
#define M_LN2l 0.6931471805599453094172321214581766L  /* log_e 2 */
#endif


#define BYTESIZE(x) ((int) ((float) (((log(x+1)/M_LN2l) + 7.99999999) / 8.0000)))


#endif
